@@ -474,7 +474,13 @@ def backfill_metrics(
             None
             , "--table_id"
             , "-tid"
-            , help="Table IDs.  E.g. -tid 123 -tid 124")
+            , help="Table IDs.  E.g. -tid 123 -tid 124"),
+
+        delete_history: Optional[bool] = typer.Option(
+            None
+            , "--delete_history"
+            , help="Delete metric run history"
+        )
 ):
     """Backfills metrics by warehouse id, schema names, and/or table ids."""
     client = cli_client_factory(bigeye_conf)
@@ -490,7 +496,7 @@ def backfill_metrics(
 
     for mid in mids:
         try:
-            client.backfill_metric(metric_ids=[mid])
+            client.backfill_metric(metric_ids=[mid], delete_history=delete_history)
         except Exception as e:
             log.exception(e)
     client.run_metric_batch(metric_ids=mids)
